@@ -1,6 +1,6 @@
-package Email::Sender::Role::HasMessage;
+package Email::Sender::Role::HasMessage 2.500;
 # ABSTRACT: an object that has a message
-$Email::Sender::Role::HasMessage::VERSION = '1.300031';
+
 use Moo::Role;
 
 #pod =attr message
@@ -29,7 +29,17 @@ Email::Sender::Role::HasMessage - an object that has a message
 
 =head1 VERSION
 
-version 1.300031
+version 2.500
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 ATTRIBUTES
 
@@ -39,11 +49,11 @@ This attribute is a message associated with the object.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
