@@ -1,6 +1,6 @@
-package Email::Sender::Transport;
+package Email::Sender::Transport 2.500;
 # ABSTRACT: a role for email transports
-$Email::Sender::Transport::VERSION = '1.300034';
+
 use Moo::Role;
 
 #pod =head1 DESCRIPTION
@@ -52,7 +52,7 @@ Email::Sender::Transport - a role for email transports
 
 =head1 VERSION
 
-version 1.300034
+version 2.500
 
 =head1 DESCRIPTION
 
@@ -62,6 +62,16 @@ L<Email::Sender::Role::CommonSending>, which it includes. The important
 difference is that Transports are often intended to be used by
 L<Email::Sender::Simple>, and they provide two methods related to that purpose.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =for Pod::Coverage is_simple allow_partial_success
 
 First, they provide an C<allow_partial_success> method which returns true or
@@ -78,11 +88,11 @@ all times.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
