@@ -1,6 +1,6 @@
-package Email::Sender::Transport::Mbox;
+package Email::Sender::Transport::Mbox 2.500;
 # ABSTRACT: deliver mail to an mbox on disk
-$Email::Sender::Transport::Mbox::VERSION = '1.300035';
+
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -126,7 +126,7 @@ Email::Sender::Transport::Mbox - deliver mail to an mbox on disk
 
 =head1 VERSION
 
-version 1.300035
+version 2.500
 
 =head1 DESCRIPTION
 
@@ -136,13 +136,23 @@ F<filename> argument to the constructor, and defaults to F<mbox>.
 The transport I<currently> assumes that the mbox is in F<mboxo> format, but
 this may change or be configurable in the future.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
