@@ -1,6 +1,6 @@
-package Email::Sender::Transport::Wrapper;
+package Email::Sender::Transport::Wrapper 2.500;
 # ABSTRACT: a mailer to wrap a mailer for mailing mail
-$Email::Sender::Transport::Wrapper::VERSION = '1.300035';
+
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -68,7 +68,7 @@ Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
 
 =head1 VERSION
 
-version 1.300035
+version 2.500
 
 =head1 DESCRIPTION
 
@@ -76,13 +76,23 @@ Email::Sender::Transport::Wrapper wraps a transport, provided as the
 C<transport> argument to the constructor.  It is provided as a simple way to
 use method modifiers to create wrapping classes.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
